.. _reference_grad:

Gradients
=========

.. module:: grad

The module :mod:`aesara.grad` allows to compute the gradient of an Aesara graph.

.. autofunction:: aesara.gradient.grad

This section of the documentation is organized as follows:

* :ref:`Derivatives in Aesara <reference_gradient_tutorial>` gives a hands-on introduction to how to build gradient graphs in Aesara.
* :ref:`Gradients API <reference_gradient_api>` is an API reference for the :mod:`aesara.gradient` module.


.. toctree::
    :maxdepth: 1
    :hidden:

    gradient_tutorial
    gradient_api
